@@ -1,4 +1,5 @@
 import collections
+import configparser
 import importlib
 import os
 import pathlib
@@ -9,7 +10,6 @@ import traceback
 import types
 import typing
 
-import six
 import uqbar.apis
 
 
@@ -51,7 +51,7 @@ class Configuration:
     _configuration_file_name = "abjad.cfg"
 
     # for caching
-    _lilypond_version_string: typing.Optional[str] = None
+    _lilypond_version_string: typing.ClassVar[str | None] = None
 
     ### INITIALIZER ###
 
@@ -95,7 +95,7 @@ class Configuration:
         """
         return self._settings.__getitem__(argument)
 
-    def __iter__(self) -> typing.Generator:
+    def __iter__(self) -> typing.Iterator[str]:
         """
         Iterates configuration settings.
         """
@@ -118,16 +118,11 @@ class Configuration:
     def _configuration_from_string(self, string):
         if "[main]" not in string:
             string = "[main]\n" + string
-        config_parser = six.moves.configparser.ConfigParser()
+        config_parser = configparser.ConfigParser()
         try:
-            if six.PY3:
-                config_parser.read_string(string)
-                configuration = dict(config_parser["main"].items())
-            else:
-                string_io = six.moves.StringIO(string)
-                config_parser.readfp(string_io)
-                configuration = dict(config_parser.items("main"))
-        except six.moves.configparser.ParsingError:
+            config_parser.read_string(string)
+            configuration = dict(config_parser["main"].items())
+        except configparser.ParsingError:
             configuration = {}
         return configuration
 
@@ -397,8 +392,6 @@ def list_all_classes(modules="abjad", ignored_classes=None):
 
         >>> for class_ in abjad.list_all_classes(modules="abjad"): class_
         <class 'abjad.bind.Wrapper'>
-        <class 'abjad.bundle.LilyPondFormatBundle'>
-        <class 'abjad.bundle.SlotContributions'>
         <class 'abjad.configuration.Configuration'>
         <class 'abjad.contextmanagers.ContextManager'>
         <class 'abjad.contextmanagers.FilesystemState'>
@@ -409,6 +402,7 @@ def list_all_classes(modules="abjad", ignored_classes=None):
         <class 'abjad.contextmanagers.TemporaryDirectory'>
         <class 'abjad.contextmanagers.TemporaryDirectoryChange'>
         <class 'abjad.contextmanagers.Timer'>
+        <class 'abjad.contributions.ContributionsBySite'>
         <class 'abjad.cyclictuple.CyclicTuple'>
         <class 'abjad.duration.Duration'>
         <class 'abjad.duration.Multiplier'>
@@ -438,7 +432,9 @@ def list_all_classes(modules="abjad", ignored_classes=None):
         <class 'abjad.indicators.KeyCluster'>
         <class 'abjad.indicators.KeySignature'>
         <class 'abjad.indicators.LaissezVibrer'>
+        <class 'abjad.indicators.LilyPondLiteral'>
         <class 'abjad.indicators.MarginMarkup'>
+        <class 'abjad.indicators.Markup'>
         <class 'abjad.indicators.MetronomeMark'>
         <class 'abjad.indicators.Mode'>
         <class 'abjad.indicators.Ottava'>
@@ -446,7 +442,6 @@ def list_all_classes(modules="abjad", ignored_classes=None):
         <class 'abjad.indicators.Repeat'>
         <class 'abjad.indicators.RepeatTie'>
         <class 'abjad.indicators.StaffChange'>
-        <class 'abjad.indicators.StaffPosition'>
         <class 'abjad.indicators.StartBeam'>
         <class 'abjad.indicators.StartGroup'>
         <class 'abjad.indicators.StartHairpin'>
@@ -530,21 +525,17 @@ def list_all_classes(modules="abjad", ignored_classes=None):
         <class 'abjad.lyproxy.LilyPondGrobInterface'>
         <class 'abjad.makers.LeafMaker'>
         <class 'abjad.makers.NoteMaker'>
-        <class 'abjad.markups.Markup'>
         <class 'abjad.math.Infinity'>
         <class 'abjad.math.NegativeInfinity'>
         <class 'abjad.meter.Meter'>
-        <class 'abjad.meter.MeterList'>
         <class 'abjad.meter.MetricAccentKernel'>
         <class 'abjad.metricmodulation.MetricModulation'>
         <class 'abjad.obgc.OnBeatGraceContainer'>
         <class 'abjad.overrides.Interface'>
-        <class 'abjad.overrides.LilyPondLiteral'>
         <class 'abjad.overrides.LilyPondOverride'>
         <class 'abjad.overrides.LilyPondSetting'>
         <class 'abjad.overrides.OverrideInterface'>
         <class 'abjad.overrides.SettingInterface'>
-        <class 'abjad.overrides.TweakInterface'>
         <class 'abjad.parentage.Parentage'>
         <class 'abjad.parsers.base.Parser'>
         <class 'abjad.parsers.parser.ContextSpeccedMusic'>
@@ -566,17 +557,11 @@ def list_all_classes(modules="abjad", ignored_classes=None):
         <class 'abjad.parsers.scheme.SchemeParser'>
         <class 'abjad.pattern.Pattern'>
         <class 'abjad.pattern.PatternTuple'>
-        <class 'abjad.pcollections.IntervalClassSegment'>
-        <class 'abjad.pcollections.IntervalClassSet'>
-        <class 'abjad.pcollections.IntervalSegment'>
-        <class 'abjad.pcollections.IntervalSet'>
         <class 'abjad.pcollections.PitchClassSegment'>
         <class 'abjad.pcollections.PitchClassSet'>
         <class 'abjad.pcollections.PitchRange'>
         <class 'abjad.pcollections.PitchSegment'>
         <class 'abjad.pcollections.PitchSet'>
-        <class 'abjad.pcollections.Segment'>
-        <class 'abjad.pcollections.Set'>
         <class 'abjad.pcollections.TwelveToneRow'>
         <class 'abjad.pitch.Accidental'>
         <class 'abjad.pitch.Interval'>
@@ -594,6 +579,7 @@ def list_all_classes(modules="abjad", ignored_classes=None):
         <class 'abjad.pitch.Octave'>
         <class 'abjad.pitch.Pitch'>
         <class 'abjad.pitch.PitchClass'>
+        <class 'abjad.pitch.StaffPosition'>
         <class 'abjad.ratio.NonreducedRatio'>
         <class 'abjad.ratio.Ratio'>
         <class 'abjad.rhythmtrees.RhythmTreeContainer'>
@@ -622,17 +608,14 @@ def list_all_classes(modules="abjad", ignored_classes=None):
         <class 'abjad.score.Tuplet'>
         <class 'abjad.score.Voice'>
         <class 'abjad.select.LogicalTie'>
-        <class 'abjad.select.Selection'>
         <class 'abjad.setclass.SetClass'>
         <class 'abjad.tag.Line'>
         <class 'abjad.tag.Tag'>
         <class 'abjad.timespan.OffsetCounter'>
         <class 'abjad.timespan.Timespan'>
         <class 'abjad.timespan.TimespanList'>
-        <class 'abjad.typedcollections.TypedCollection'>
-        <class 'abjad.typedcollections.TypedFrozenset'>
-        <class 'abjad.typedcollections.TypedList'>
-        <class 'abjad.typedcollections.TypedTuple'>
+        <class 'abjad.tweaks.Bundle'>
+        <class 'abjad.tweaks.Tweak'>
         <class 'abjad.verticalmoment.VerticalMoment'>
 
     """
