@@ -3,20 +3,19 @@ Classes and functions for modeling spanners: beams, hairpins, slurs, etc.
 """
 import typing
 
-from . import _iterate
+from . import _iterlib
 from . import bind as _bind
 from . import duration as _duration
 from . import dynamic as _dynamic
 from . import enums as _enums
 from . import indicators as _indicators
-from . import iterate as iterate_
+from . import iterate as _iterate
 from . import parentage as _parentage
 from . import score as _score
 from . import select as _select
 from . import sequence as _sequence
 from . import tag as _tag
 from . import tweaks as _tweaks
-from . import typings as _typings
 
 
 def _apply_tweaks(argument, tweaks, i=None, total=None):
@@ -51,7 +50,7 @@ def beam(
     selector: typing.Callable = lambda _: _select.leaves(_),
     span_beam_count: int = None,
     start_beam: _indicators.StartBeam = None,
-    stemlet_length: _typings.Number = None,
+    stemlet_length: int | float | None = None,
     stop_beam: _indicators.StopBeam = None,
     tag: _tag.Tag = None,
 ) -> None:
@@ -81,7 +80,7 @@ def beam(
     """
     assert callable(selector)
     argument = selector(argument)
-    original_leaves = list(iterate_.leaves(argument))
+    original_leaves = list(_iterate.leaves(argument))
     silent_prototype = (_score.MultimeasureRest, _score.Rest, _score.Skip)
 
     def _is_beamable(argument, beam_rests=False):
@@ -600,8 +599,8 @@ def glissando(
             %! abjad.glissando(7)
             \glissando
             f'8
-            %! abjad.glissando(7)
             %! SHOW_TO_JOIN_BROKEN_SPANNERS
+            %! abjad.glissando(7)
             %@% \glissando
         }
 
@@ -626,39 +625,39 @@ def glissando(
             c'8
             %! abjad.glissando(7)
             \glissando
-            %! abjad.glissando(0)
-            %! SHOW_TO_JOIN_BROKEN_SPANNERS
             %! RIGHT_BROKEN
+            %! SHOW_TO_JOIN_BROKEN_SPANNERS
+            %! abjad.glissando(0)
             \hide NoteHead
-            %! abjad.glissando(0)
-            %! SHOW_TO_JOIN_BROKEN_SPANNERS
             %! RIGHT_BROKEN
+            %! SHOW_TO_JOIN_BROKEN_SPANNERS
+            %! abjad.glissando(0)
             \override Accidental.stencil = ##f
-            %! abjad.glissando(0)
-            %! SHOW_TO_JOIN_BROKEN_SPANNERS
             %! RIGHT_BROKEN
+            %! SHOW_TO_JOIN_BROKEN_SPANNERS
+            %! abjad.glissando(0)
             \override NoteColumn.glissando-skip = ##t
-            %! abjad.glissando(0)
-            %! SHOW_TO_JOIN_BROKEN_SPANNERS
             %! RIGHT_BROKEN
+            %! SHOW_TO_JOIN_BROKEN_SPANNERS
+            %! abjad.glissando(0)
             \override NoteHead.no-ledgers = ##t
             d'8
             e'8
-            %! abjad.glissando(4)
             %! HIDE_TO_JOIN_BROKEN_SPANNERS
             %! RIGHT_BROKEN
+            %! abjad.glissando(4)
             \revert Accidental.stencil
-            %! abjad.glissando(4)
             %! HIDE_TO_JOIN_BROKEN_SPANNERS
             %! RIGHT_BROKEN
+            %! abjad.glissando(4)
             \revert NoteColumn.glissando-skip
-            %! abjad.glissando(4)
             %! HIDE_TO_JOIN_BROKEN_SPANNERS
             %! RIGHT_BROKEN
+            %! abjad.glissando(4)
             \revert NoteHead.no-ledgers
-            %! abjad.glissando(4)
             %! HIDE_TO_JOIN_BROKEN_SPANNERS
             %! RIGHT_BROKEN
+            %! abjad.glissando(4)
             \undo \hide NoteHead
             f'8
         }
@@ -686,56 +685,56 @@ def glissando(
             c'8
             %! abjad.glissando(7)
             \glissando
-            %! abjad.glissando(0)
-            %! SHOW_TO_JOIN_BROKEN_SPANNERS
             %! RIGHT_BROKEN
+            %! SHOW_TO_JOIN_BROKEN_SPANNERS
+            %! abjad.glissando(0)
             \hide NoteHead
-            %! abjad.glissando(0)
-            %! SHOW_TO_JOIN_BROKEN_SPANNERS
             %! RIGHT_BROKEN
+            %! SHOW_TO_JOIN_BROKEN_SPANNERS
+            %! abjad.glissando(0)
             \override Accidental.stencil = ##f
-            %! abjad.glissando(0)
-            %! SHOW_TO_JOIN_BROKEN_SPANNERS
             %! RIGHT_BROKEN
+            %! SHOW_TO_JOIN_BROKEN_SPANNERS
+            %! abjad.glissando(0)
             \override NoteColumn.glissando-skip = ##t
-            %! abjad.glissando(0)
-            %! SHOW_TO_JOIN_BROKEN_SPANNERS
             %! RIGHT_BROKEN
+            %! SHOW_TO_JOIN_BROKEN_SPANNERS
+            %! abjad.glissando(0)
             \override NoteHead.no-ledgers = ##t
             d'8
             e'8
-            %! abjad.glissando(4)
             %! HIDE_TO_JOIN_BROKEN_SPANNERS
             %! RIGHT_BROKEN
+            %! abjad.glissando(4)
             \revert Accidental.stencil
-            %! abjad.glissando(4)
             %! HIDE_TO_JOIN_BROKEN_SPANNERS
             %! RIGHT_BROKEN
+            %! abjad.glissando(4)
             \revert NoteColumn.glissando-skip
-            %! abjad.glissando(4)
             %! HIDE_TO_JOIN_BROKEN_SPANNERS
             %! RIGHT_BROKEN
+            %! abjad.glissando(4)
             \revert NoteHead.no-ledgers
-            %! abjad.glissando(4)
             %! HIDE_TO_JOIN_BROKEN_SPANNERS
             %! RIGHT_BROKEN
+            %! abjad.glissando(4)
             \undo \hide NoteHead
             f'8
-            %! abjad.glissando(5)
-            %! SHOW_TO_JOIN_BROKEN_SPANNERS
             %! RIGHT_BROKEN_SHOW_NEXT
+            %! SHOW_TO_JOIN_BROKEN_SPANNERS
+            %! abjad.glissando(5)
             %@% \revert Accidental.stencil
-            %! abjad.glissando(5)
-            %! SHOW_TO_JOIN_BROKEN_SPANNERS
             %! RIGHT_BROKEN_SHOW_NEXT
+            %! SHOW_TO_JOIN_BROKEN_SPANNERS
+            %! abjad.glissando(5)
             %@% \revert NoteColumn.glissando-skip
-            %! abjad.glissando(5)
-            %! SHOW_TO_JOIN_BROKEN_SPANNERS
             %! RIGHT_BROKEN_SHOW_NEXT
+            %! SHOW_TO_JOIN_BROKEN_SPANNERS
+            %! abjad.glissando(5)
             %@% \revert NoteHead.no-ledgers
-            %! abjad.glissando(5)
-            %! SHOW_TO_JOIN_BROKEN_SPANNERS
             %! RIGHT_BROKEN_SHOW_NEXT
+            %! SHOW_TO_JOIN_BROKEN_SPANNERS
+            %! abjad.glissando(5)
             %@% \undo \hide NoteHead
         }
 
@@ -757,24 +756,24 @@ def glissando(
         >>> print(string)
         \new Staff
         {
-            %! abjad.glissando(2)
             %! HIDE_TO_JOIN_BROKEN_SPANNERS
             %! LEFT_BROKEN
+            %! abjad.glissando(2)
             \hide NoteHead
-            %! abjad.glissando(2)
             %! HIDE_TO_JOIN_BROKEN_SPANNERS
             %! LEFT_BROKEN
+            %! abjad.glissando(2)
             \override Accidental.stencil = ##f
-            %! abjad.glissando(2)
             %! HIDE_TO_JOIN_BROKEN_SPANNERS
             %! LEFT_BROKEN
+            %! abjad.glissando(2)
             \override NoteHead.no-ledgers = ##t
             c'8
             %! abjad.glissando(7)
             \glissando
-            %! abjad.glissando(3)
             %! HIDE_TO_JOIN_BROKEN_SPANNERS
             %! LEFT_BROKEN
+            %! abjad.glissando(3)
             \override NoteColumn.glissando-skip = ##t
             d'8
             e'8
@@ -955,11 +954,11 @@ def glissando(
         raise Exception(message)
 
     def _is_last_in_tie_chain(leaf):
-        logical_tie = _iterate._get_logical_tie_leaves(leaf)
+        logical_tie = _iterlib._get_logical_tie_leaves(leaf)
         return leaf is logical_tie[-1]
 
     def _next_leaf_changes_current_pitch(leaf):
-        next_leaf = _iterate._get_leaf(leaf, 1)
+        next_leaf = _iterlib._get_leaf(leaf, 1)
         if (
             isinstance(leaf, _score.Note)
             and isinstance(next_leaf, _score.Note)
@@ -982,7 +981,7 @@ def glissando(
                 note_head.is_parenthesized = True
 
     def _previous_leaf_changes_current_pitch(leaf):
-        previous_leaf = _iterate._get_leaf(leaf, -1)
+        previous_leaf = _iterlib._get_leaf(leaf, -1)
         if (
             isinstance(leaf, _score.Note)
             and isinstance(previous_leaf, _score.Note)
@@ -1683,7 +1682,7 @@ def tie(
     argument: _score.Component | typing.Sequence[_score.Component],
     *,
     direction: _enums.Vertical | None = None,
-    repeat: bool | _typings.IntegerPair | typing.Callable = False,
+    repeat: bool | tuple[int, int] | typing.Callable = False,
     selector: typing.Callable = lambda _: _select.leaves(_),
     tag: _tag.Tag = None,
 ) -> None:
